@@ -119,8 +119,10 @@ class AbstractAsyncServiceBatchCE(ITaskHandler, IBatchOutputer, ICacheAbleHandle
             except Exception as e:
                 return ResultVO(FAIL_CODE, f"任务:{taskLogId} 请求{request.url} 失败,请求出错: {str(e)}")
 
-            if r.status_code != 200 or r.content is None:
-                return ResultVO(FAIL_CODE, f"任务:{taskLogId} 请求{request.url} 失败,请求出错: {r.content}")
+            succeeded, message = self.analysis_sync_response(r.status_code, r.content, r.headers)
+
+            if not succeeded:
+                return ResultVO(FAIL_CODE, f"任务:{taskLogId} 请求{request.url} 失败,请求出错: {message}")
 
         return DOING
 
@@ -210,6 +212,20 @@ class AbstractAsyncServiceBatchCE(ITaskHandler, IBatchOutputer, ICacheAbleHandle
                 output_stream.queue.clear()
 
     # region 固定方法相关
+
+    def analysis_sync_response(self, status_code: int, body, headers):
+        """
+        允许自定义解析同步请求的返回
+        :param status_code:  http的状态
+        :param body:  同步响应的 body
+        :param headers:  同步响应的header
+        :return:   成功与否,消息提示
+        """
+        if status_code != 200 or body is None:
+            self.task_logger.error(Exception(f"同步调用异步rest失败,status:{status_code}, message:{body}"))
+            return False, body
+        return True, None
+
     def get_execution_message_cache(self):
         """
                 返回message_cache
