@@ -14,7 +14,7 @@ class FactDatasource(object):
 
     def __init__(self, site, projectCode, code, name, type, connection, target,
                  id=None, description=None, credentials=None, model=None, ttl=None, tags=None,
-                 privilege=None,
+                 privilege=None, schema=None,
                  **kwargs):
         """
         描述数据源的对象
@@ -30,6 +30,7 @@ class FactDatasource(object):
         :param target: 事实库的数据目标,必填,FILE文件名/MYSQL,ORACLE表名/redis(key的前缀)?/kafka队列名/es索引名/mongo Collection名/
             sobeyHive 就是目标索引名 entity/ CUSTOM是 handler的名字/AMQP exchange:routingKey/ JMS 发送消息的目标位置 https://stomp.github.io/stomp-specification-1.2.html#SEND
             algorithm如果是空，表示文件夹，如果不空，表示文件
+        :param schema: 事实库的数据目标的schema,选填,在有些数据库里面是需要的, 例如oracle
         :param id: 事实库在数据库中的主键,添加的时候不填
         :param description: 事实库描述/备注,允许中文/英文大小写字母加数字,最大512个字符
         :param credentials: 数据的认证的字符串,JDBC/REDIS/ES/KAFKA/AMQP 就是 用户名:密码   MONGO就是 username:password@database  sobeyHive就是 站点名  CUSTOM 没意义
@@ -48,6 +49,7 @@ class FactDatasource(object):
         self.connection = connection
         self.credentials = credentials
         self.target = target
+        self.schema = schema
         self.model: MetaModel = MetaModel(id=model) if model is not None else None
         self.ttl = ttl
         self.tags = tags
@@ -56,6 +58,12 @@ class FactDatasource(object):
 
         self._source_name = f'fd_{self.site}_{self.projectCode}_{self.code}'
 
+    def get_target_with_schema(self):
+        if self.schema is None or len(self.schema) == 0:
+            return self.target
+        else:
+            return self.schema + "." + self.target
+
     def get_source_name(self):
         return self._source_name
 
@@ -74,7 +82,7 @@ class FactDatasourceTypeEnum(Enum):
     # python中JMS类型使用的是stomp协议，如果配置的JMS类型，需要开启对应消息组件的stomp支持
     JMS = 'JMS'
     ALGORITHM = 'ALGORITHM'
-    REF = 'REF'       # 表示这个FD是关联的其他的FD
+    REF = 'REF'  # 表示这个FD是关联的其他的FD
     FTP = 'FTP'
     S3 = 'S3'
     NAS = 'NAS'
