@@ -18,8 +18,11 @@ def check_instance_avaliable(app_name=FICUS_APP_NAME):
 
 
 from .ComputeExecutionClient import *
+from .DataAlgorithmClient import *
 from .DataCrawlClient import *
+from .FactDatasourceClient import *
 from .HandlerLogClient import *
 from .JobScheduleClient import *
 from .ScheduleCacheClient import *
 from .ScheduleJobTaskLogClient import *
+from .FactDatasourceManageClient import *
