@@ -18,7 +18,7 @@ redis_url: str = annotation.get_value("${redis.url:}")
 
 if redis_url is None or redis_url.strip() == '':
     # 说明是新的格式
-    database = annotation.get_value("${spring.data.redis.sentinel.nodes:0}")
+    database = annotation.get_value("${spring.data.redis.database:0}")
     password = annotation.get_value("${spring.data.redis.password:}")
     nodes = annotation.get_value("${spring.data.redis.sentinel.nodes:}")
     if nodes is None or nodes == '':
