@@ -4,6 +4,7 @@
 # Created on 2019/1/21
 from abc import abstractmethod
 
+import logging
 import requests
 from munch import Munch
 
@@ -18,6 +19,7 @@ from factdatasource.message.FactDatasourceMessageHanlder import FactDatasourceCh
 from libs.utils import Singleton
 from service.FactDatasourceService import FactDatasourceService
 
+log = logging.getLogger('Ficus')
 
 class FactDatasourceProxy(object):
 
@@ -747,6 +749,7 @@ class FactDatasourceProxyFactory(Singleton):
             mode = distributed_mode()
 
         if mode:
+            log.info("服务启动,使用本地模式FD服务")
             # 注册本地数据源
             register_jdbc_default_datasource()
             # 注册kafka默认的数据源
@@ -756,6 +759,7 @@ class FactDatasourceProxyFactory(Singleton):
             # 获取本地操作实例
             self.__instance = DistributedFactDatasourceProxy.instance()
         else:
+            log.info("服务启动,使用中心模式FD服务")
             self.__instance = CentralizedFactDatasourceProxy.instance()
         return self.__instance
 
