@@ -83,7 +83,7 @@ class MultipleJdbcDatasource(DatasourceListener, MultipleBaseDatasource, Singlet
         if not source_name:
             raise IllegalArgumentException(f'删除数据源参数错误:source_name不能为空')
 
-        target: JdbcDatasource = self._target_dataSources.pop(source_name)
+        target: JdbcDatasource = self._target_dataSources.pop(source_name, None)
         if target:
             if target.only_one_source():
                 target.close_client()
@@ -179,7 +179,7 @@ class JdbcDatasource(BaseDatasource):
         :return:  dialect[+driver]://user:password@host/dbname[?key=value..]
         """
         if not jdbc_type or not jdbc_url:
-             raise IllegalArgumentException('构造url参数错误。')
+            raise IllegalArgumentException('构造url参数错误。')
 
         # 支持sqlalchemy进行连接的url
         if jdbc_type == JdbcTypeEnum.MYSQL:
@@ -213,7 +213,7 @@ class JdbcDatasource(BaseDatasource):
 
             r = url.parse_url(url_prefix)
             if 'databaseName' in url_param:
-                database = url_param.pop('databaseName')
+                database = url_param.pop('databaseName', None)
             else:
                 raise FDConfigException(f'数据库连接{jdbc_url}未配置databaseName值。')
 
@@ -230,7 +230,8 @@ class JdbcDatasource(BaseDatasource):
 
             path = '/' + str(database)
 
-            result_url = Url(scheme=sqlalchemy_scheme.value, auth=self._credentials, host=r.host, port=r.port, path=path, query=query, fragment=r.fragment)
+            result_url = Url(scheme=sqlalchemy_scheme.value, auth=self._credentials, host=r.host, port=r.port,
+                             path=path, query=query, fragment=r.fragment)
         elif jdbc_type == JdbcTypeEnum.ORACLE:
             # JDBC的常用形式是
             # 1.普通SID方式
@@ -284,20 +285,23 @@ class JdbcDatasource(BaseDatasource):
             else:
                 dsn = cx_Oracle.makedsn(host, port, sid=sid)
 
-            credentials = str(self._credentials)+'@' if self._credentials else ''
+            credentials = str(self._credentials) + '@' if self._credentials else ''
             return f'{sqlalchemy_scheme.value}://{credentials}{dsn}'
         else:
             # 默认可以使用的比较通用的构造方式
-            r = url.parse_url(jdbc_url.split(":",1)[1])
+            r = url.parse_url(jdbc_url.split(":", 1)[1])
             # sqlalchemy mysql 这里中文一直是乱码，暂时先手动设置下编码
             query = r.query
             if jdbc_type == JdbcTypeEnum.MYSQL or jdbc_type == JdbcTypeEnum.VERNOX:
                 if not query:
                     query = 'charset=utf8mb4'
                 elif str(query).lower().find('charset=') == -1:
-                    query = query + '&charset=utf8'
+                    query = query + '&charset=utf8mb4'
+                # 需要去掉 useSSL=true/false
+                query = "&".join(list(filter(lambda x: "useSSL" not in x, query.split("&"))))
 
-            result_url = Url(scheme=sqlalchemy_scheme.value, auth=self._credentials, host=r.host, port=r.port, path=r.path, query=query, fragment=r.fragment)
+            result_url = Url(scheme=sqlalchemy_scheme.value, auth=self._credentials, host=r.host, port=r.port,
+                             path=r.path, query=query, fragment=r.fragment)
         return result_url.url
 
 
