@@ -242,7 +242,7 @@ class GraphdbFactDatasourceContext(AbstractFactDatasourceContext, SqlableDeleteC
         清空数据
         :return:
         """
-        table = self.fd().target
+        table = self.fd().get_target_with_schema()
         source_name = self.fd().get_source_name()
         try:
             costomer_context.set_source(source_name)
@@ -282,7 +282,7 @@ class GraphdbFactDatasourceContext(AbstractFactDatasourceContext, SqlableDeleteC
         source_name = self.fd().get_source_name()
         try:
             costomer_context.set_source(source_name)
-            query = self.delete_condition_sql(self.fd().target, condition_groups)
+            query = self.delete_condition_sql(self.fd().get_target_with_schema(), condition_groups)
             self.dao.delete_by_query(query.replace("DELETE FROM", "DELETE NODE FROM", 1))
         except Exception as e:
             error = f'事实库{source_name}执行delete操作发生异常, {str(e)}'
