@@ -415,7 +415,7 @@ class JdbcFactDatasourceContext(AbstractFactDatasourceContext, SqlableDeleteCond
             if isinstance(value, str):
                 v = value
             elif isinstance(value, list) or isinstance(value, dict):
-                v = json.dumps(value)
+                v = json.dumps(value, ensure_ascii=False)
             elif isinstance(value, tuple) or isinstance(value, set):
                 v = str(value)
             else:
