@@ -8,6 +8,7 @@ import re
 import threading
 import uuid
 import os
+import ctypes
 
 from api.model.FactDatasource import JdbcTypeEnum
 
@@ -180,3 +181,23 @@ def delete_file(file: str):
     else:
         import shutil
         shutil.rmtree(file)
+
+
+def stop_thread(thread):
+    """
+    强制停止线程
+    :param thread:
+    :return:
+    """
+    class KilledException(Exception):
+        pass
+
+    tid = ctypes.c_long(thread.ident)
+    exctype = KilledException  #也可以用其它异常，如果用SystemExit不会打印异常信息
+    res = ctypes.pythonapi.PyThreadState_SetAsyncExc(tid, ctypes.py_object(exctype))
+    if res == 0:
+        raise ValueError("线程ID无效")
+    elif res != 1:
+        # if it returns a number greater than one, you're in trouble, and you should call it again with exc=NULL to revert the effect
+        ctypes.pythonapi.PyThreadState_SetAsyncExc(tid, None)
+        raise SystemError("停止线程失败")
\ No newline at end of file
