@@ -846,7 +846,7 @@ class DiscoveryClient:
                 time.sleep(self.__cache_time_in_secs)
                 self.__fetch_delta()
             except Exception as e:
-                _logger.error(f'【eureka-client】PID:{os.getpid()}, 获取apps异常:{str(e)}')
+                _logger.error(f'PID:{os.getpid()}, 获取delta异常:{str(e)}')
 
     @property
     def applications(self):
@@ -881,24 +881,19 @@ class DiscoveryClient:
         def do_pull(url):  # the actual function body
             self.__applications = get_applications(url, self.__regions)
             self.__delta = self.__applications
-            _logger.info(f'【eureka-client】PID:{os.getpid()}, 成功全量获取apps')
         self.__try_all_eureka_server(do_pull)
 
     def __fetch_delta(self):
         def do_fetch(url):
-            _logger.info(f'【eureka-client】PID:{os.getpid()}, 开始获取delta')
             if self.__applications is None or len(self.__applications.applications) == 0:
                 self.__pull_full_registry()
                 return
             delta = get_delta(url, self.__regions)
-            _logger.info(f'【eureka-client】PID:{os.getpid()}, 成功获取delta')
             _logger.debug("delta got: v.%s::%s" % (delta.versionsDelta, delta.appsHashcode))
             if self.__delta is not None \
                     and delta.versionsDelta == self.__delta.versionsDelta \
                     and delta.appsHashcode == self.__delta.appsHashcode:
-                _logger.info(f'【eureka-client】PID:{os.getpid()}, 没有变化delta')
                 return
-            _logger.info(f'【eureka-client】PID:{os.getpid()}, 合并delta，sefl:{self.__delta.versionsDelta}, remote：{delta.versionsDelta}')
             self.__merge_delta(delta)
             self.__delta = delta
             if not self.__is_hash_match():
