@@ -32,10 +32,10 @@ def build_param_def(conf_param_defs:list, is_input_param:bool) -> list:
         # 获取配置文件读取的字段信息
         if "model" in conf_param_def and len(conf_param_def["model"]) > 0:
             param_def = {
-                "type": conf_param_def["type"].upper(),
-                "description": conf_param_def["description"],
-                "matchTags": conf_param_def["matchTags"],
-                "matchParams": conf_param_def["matchParams"],
+                "type": conf_param_def.get("type").upper(),
+                "description": conf_param_def.get("description"),
+                "matchTags": conf_param_def.get("matchTags"),
+                "matchParams": conf_param_def.get("matchParams"),
                 "isInputParam": is_input_param,
                 "createTime": time.strftime("%Y-%m-%d %H:%M:%S"),
                 "metaModel": {
@@ -49,14 +49,14 @@ def build_param_def(conf_param_defs:list, is_input_param:bool) -> list:
 
             for conf_field in conf_param_def["model"]:
                 meta_model_field = {
-                    "fieldName": conf_field["fieldName"],
-                    "description": conf_field["description"],
-                    "dataType": conf_field["dataType"].upper(),
-                    "primaryKey": conf_field["primaryKey"],
-                    "maxLength": conf_field["maxLength"],
-                    "minLength": conf_field["minLength"],
-                    "defaultValue": conf_field["defaultValue"],
-                    "nullable": conf_field["nullable"],
+                    "fieldName": conf_field.get("fieldName"),
+                    "description": conf_field.get("description"),
+                    "dataType": conf_field.get("dataType").upper(),
+                    "primaryKey": conf_field.get("primaryKey"),
+                    "maxLength": conf_field.get("maxLength"),
+                    "minLength": conf_field.get("minLength"),
+                    "defaultValue": conf_field.get("defaultValue"),
+                    "nullable": conf_field.get("nullable"),
                     "multiple": False
                 }
                 param_def["metaModel"]["fields"].append(meta_model_field)
@@ -67,15 +67,16 @@ def build_param_def(conf_param_defs:list, is_input_param:bool) -> list:
 
 def build_data_algorithm(conf_algorithm:dict) -> dict:
     data_algorithm = {
-        "code": conf_algorithm["code"],
-        "name": conf_algorithm["name"],
-        "description": conf_algorithm["description"],
-        "actorName": conf_algorithm["actorName"],
-        "handler": conf_algorithm["handler"],
-        "author": conf_algorithm["author"],
-        "version": conf_algorithm["version"],
-        "categories": conf_algorithm["categories"],
-        "shardable": conf_algorithm["shardable"],
+        "site": conf_algorithm.get("site"),
+        "code": conf_algorithm.get("code"),
+        "name": conf_algorithm.get("name"),
+        "description": conf_algorithm.get("description"),
+        "actorName": conf_algorithm.get("actorName"),
+        "handler": conf_algorithm.get("handler"),
+        "author": conf_algorithm.get("author"),
+        "version": conf_algorithm.get("version"),
+        "categories": conf_algorithm.get("categories"),
+        "shardable": conf_algorithm.get("shardable"),
         "inputParamDefs": list(),
         "paramDefs": list(),
         "enable": True,
@@ -86,10 +87,10 @@ def build_data_algorithm(conf_algorithm:dict) -> dict:
     if "inputParamDefs" in conf_algorithm and len(conf_algorithm["inputParamDefs"]) > 0:
         for conf_input_param_def in conf_algorithm["inputParamDefs"]:
             input_param_def = {
-                "code" : conf_input_param_def["code"],
-                "dataType": conf_input_param_def["dataType"].upper(),
-                "description": conf_input_param_def["description"],
-                "required": conf_input_param_def["required"]
+                "code" : conf_input_param_def.get("code"),
+                "dataType": conf_input_param_def.get("dataType").upper(),
+                "description": conf_input_param_def.get("description"),
+                "required": conf_input_param_def.get("required")
             }
             data_algorithm["inputParamDefs"].append(input_param_def)
 
